@@ -3,8 +3,8 @@
 *
 * Main file for the mighty GOK
 *
-* Copyright 2001 - 2004 Sun Microsystems, Inc.,
-* Copyright 2001 - 2004 University Of Toronto*
+* Copyright 2001-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
@@ -32,6 +32,7 @@
 #include <signal.h>
 #include <gnome.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n.h>
 #include <cspi/spi.h>
 #include <libbonobo.h>
 #include <bonobo-activation/bonobo-activation.h>
@@ -1937,43 +1938,31 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 	gtk_window_set_default_size (GTK_WINDOW (window1), m_OurResizeWidth, m_OurResizeHeight);
 
 	fixed1 = gtk_fixed_new ();
-	gtk_widget_ref (fixed1);
-	gtk_object_set_data_full (GTK_OBJECT (window1), "fixed1", fixed1,
-                            (GtkDestroyNotify) gtk_widget_unref);
+	g_object_ref (fixed1);
+	g_object_set_data_full (G_OBJECT (window1), "fixed1", fixed1,
+				(GDestroyNotify) g_object_unref);
 	gtk_widget_show (fixed1);
 	gtk_container_add (GTK_CONTAINER (window1), fixed1);
 
-	gtk_signal_connect (GTK_OBJECT (window1), "motion_notify_event",
-                      GTK_SIGNAL_FUNC (on_window1_motion_notify_event),
-                      NULL);
-
-	gtk_signal_connect (GTK_OBJECT (window1), "leave_notify_event",
-                      GTK_SIGNAL_FUNC (on_window1_leave_notify_event),
-                      NULL);
-
-	gtk_signal_connect (GTK_OBJECT (window1), "enter_notify_event",
-                      GTK_SIGNAL_FUNC (on_window1_enter_notify_event),
-                      NULL);
-
 	gtk_widget_add_events (window1, GDK_POINTER_MOTION_MASK);
 
-	gtk_signal_connect (GTK_OBJECT (window1), "size_allocate",
-                      GTK_SIGNAL_FUNC (on_window1_size_allocate),
-                      NULL);
-                      
-	gtk_signal_connect (GTK_OBJECT (window1), "delete_event",
-                      GTK_SIGNAL_FUNC (on_window1_delete_event),
-                      NULL);
-
-	gtk_signal_connect (GTK_OBJECT (window1), "configure_event",
-                      GTK_SIGNAL_FUNC (on_window1_configure_event),
-                      NULL);
-					  
-	gtk_signal_connect (GTK_OBJECT (window1), "window_state_event",
-                      GTK_SIGNAL_FUNC (on_gok_window_state_event),
-                      NULL);
+	g_signal_connect (window1, "motion_notify_event",
+			  G_CALLBACK (on_window1_motion_notify_event), NULL);
+	g_signal_connect (window1, "leave_notify_event",
+			  G_CALLBACK (on_window1_leave_notify_event), NULL);
+	g_signal_connect (window1, "enter_notify_event",
+			  G_CALLBACK (on_window1_enter_notify_event), NULL);
+	g_signal_connect (window1, "size_allocate",
+			  G_CALLBACK (on_window1_size_allocate), NULL);
+	g_signal_connect (window1, "delete_event",
+			  G_CALLBACK (on_window1_delete_event), NULL);
+	g_signal_connect (window1, "configure_event",
+			  G_CALLBACK (on_window1_configure_event), NULL);
+	g_signal_connect (window1, "window_state_event",
+			  G_CALLBACK (on_gok_window_state_event), NULL);
 
 	gok_log_leave();
+
 	return window1;
 }
 
@@ -2178,7 +2167,7 @@ gok_main_read_keyboards_from_dir (const char *directory, GokKeyboard *keyboard)
 	struct dirent* pDirectoryEntry;
 	gchar* filename;
 	gchar* complete_path;
-	GList* langlist = NULL;
+	const gchar * const *langlist;
 	gchar *dirtemp;
 
 	gok_log_enter();
@@ -2186,18 +2175,13 @@ gok_main_read_keyboards_from_dir (const char *directory, GokKeyboard *keyboard)
 	pDirectoryKeyboards = NULL;
 
 	/* find the locale specific keyboards */
-	langlist = (GList*) gnome_i18n_get_language_list(NULL);
-	if (langlist != NULL) {
-		gint i = 0;
-		guint l = g_list_length(langlist);
-		while ((i < l)) {
-			dirtemp = g_build_filename (directory, g_list_nth_data(langlist, i), NULL);
-			pDirectoryKeyboards = opendir (dirtemp);
-			if (pDirectoryKeyboards) 
-				break;
-			g_free (dirtemp);
-			i++;
-		}
+	langlist = g_get_language_names ();
+	while (*langlist) {
+		dirtemp = g_build_filename (directory, *langlist++, NULL);
+		pDirectoryKeyboards = opendir (dirtemp);
+		if (pDirectoryKeyboards) 
+			break;
+		g_free (dirtemp);
 	}
 
 	if (pDirectoryKeyboards == NULL) { /* no locale specific directory found */
@@ -2734,7 +2718,7 @@ void gok_main_store_window_center ()
 
 	/* get the center of the current window */	
 	gdk_window_get_position (m_pWindowMain->window, &winX, &winY);
-	gdk_window_get_size (m_pWindowMain->window, &winWidthCurrent, &winHeightCurrent);
+	gdk_drawable_get_size (m_pWindowMain->window, &winWidthCurrent, &winHeightCurrent);
 	winX +=  winWidthCurrent / 2;	
 	winY +=  winHeightCurrent / 2;
 
@@ -2812,7 +2796,6 @@ gok_main_close()
 	gok_data_close();
 
 	closeSwitchApi();
-	gok_sound_shutdown();
 	gok_modifier_close();
 	gok_action_close();
 	gok_feedback_close();
@@ -2921,7 +2904,7 @@ gok_main_window_contains_pointer (void)
 	  gdk_window_get_position (widget->window, &x, &y);
 	  x = px-x;
 	  y = py-y;
-	  gdk_window_get_size (widget->window, &w, &h);
+	  gdk_drawable_get_size (widget->window, &w, &h);
 	}
 	if (x < 0 || y < 0 || x > w || y > h)
 	  return FALSE;
